{% extends 'shop/base.html' %}

{% block title %} 
    Add to cart
{% endblock title %}

{% block content %}
<div class="container">
    <h3>Product added to cart successfully </h3>
</div>
{% endblock content %}