<!DOCTYPE html>
<html>
<head>
    <title>Main Page</title>
    <link rel="stylesheet" href="/static/css/style.css">
    <link href="//maxcdn.bootstrapcdn.com/bootstrap/3.3.0/css/bootstrap.min.css" rel="stylesheet" id="bootstrap-css">
    <script src="//maxcdn.bootstrapcdn.com/bootstrap/3.3.0/js/bootstrap.min.js"></script>
    <script src="//code.jquery.com/jquery-1.11.1.min.js"></script>
</head>
<body>
    <div class="container">
   <div class="row text-center">
            <div class="col-md-12">
            <br/><br/>
             
            <br/><br/>
            </div>
    </div>        
           
  <div class="row db-padding-btm db-attached">
        <div class="col-xs-12 col-sm-3 col-md-3 col-lg-3">
            <div class="db-wrapper">
                <div class="db-pricing-eleven db-bk-color-one">
                    <div class="price">
                        <sup></sup>10
                            <small>per week</small>
                    </div>
                    <div class="type">
                        BASIC PLAN
                    </div>
                    <ul>

                        <li><i class="glyphicon glyphicon-print"></i>30+ Accounts </li>
                        <li><i class="glyphicon glyphicon-time"></i>150+ Projects </li>
                        <li><i class="glyphicon glyphicon-trash"></i>Lead Required</li>
                    </ul>
                    <div class="pricing-footer">

                        <a href="{% url 'subscribe' %}?sub_plan=Basic" class="btn db-button-color-square btn-lg">Subscribe with esewa</a>
                        <a href="{% url 'khaltirequest' %}?sub_plan=Basic" class="btn db-button-color-square btn-lg">Subscribe with khalti</a>
                    </div>
                </div>
            </div>
        </div>
        <div class="col-xs-12 col-sm-3 col-md-3 col-lg-3">
              <div class="db-wrapper">
            <div class="db-pricing-eleven db-bk-color-two popular">
                <div class="price">
                    <sup></sup>20
                            <small>per week</small>
                </div>
                <div class="type">
                    MEDIUM PLAN
                </div>
                <ul>

                    <li><i class="glyphicon glyphicon-print"></i>30+ Accounts </li>
                    <li><i class="glyphicon glyphicon-time"></i>150+ Projects </li>
                    <li><i class="glyphicon glyphicon-trash"></i>Lead Required</li>
                </ul>
                <div class="pricing-footer">

                    <a href="{% url 'subscribe' %}?sub_plan=Medium" class="btn db-button-color-square btn-lg">Subscribe with esewa</a>
                    <a href="{% url 'khaltirequest' %}?sub_plan=Medium" class="btn db-button-color-square btn-lg">Subscribe with khalti </a>
                </div>
            </div>
                  </div>
        </div>
        <div class="col-xs-12 col-sm-3 col-md-3 col-lg-3">
              <div class="db-wrapper">
            <div class="db-pricing-eleven db-bk-color-three">
                <div class="price">
                    <sup></sup>30
                            <small>per week</small>
                </div>
                <div class="type">
                    ADVANCE PLAN
                </div>
                <ul>

                    <li><i class="glyphicon glyphicon-print"></i>30+ Accounts </li>
                    <li><i class="glyphicon glyphicon-time"></i>150+ Projects </li>
                    <li><i class="glyphicon glyphicon-trash"></i>Lead Required</li>
                </ul>
                <div class="pricing-footer">

                    <a href="{% url 'subscribe' %}?sub_plan=Advanced" class="btn db-button-color-square btn-lg">Subscribe with esewa</a>

                    <a href="{% url 'khaltirequest' %}?sub_plan=Advanced" class="btn db-button-color-square btn-lg">Subscribe with khalti</a>
                </div>
            </div>
                  </div>
        </div>
        <div class="col-xs-12 col-sm-3 col-md-3 col-lg-3">
              <div class="db-wrapper">
            <div class="db-pricing-eleven db-bk-color-six">
                <div class="price">
                    <sup></sup>40
                            <small>per week</small>
                </div>
                <div class="type">
                    EXTENDED PLAN
                </div>
                <ul>

                    <li><i class="glyphicon glyphicon-print"></i>30+ Accounts </li>
                    <li><i class="glyphicon glyphicon-time"></i>150+ Projects </li>
                    <li><i class="glyphicon glyphicon-trash"></i>Lead Required</li>
                </ul>
                <div class="pricing-footer">

                    <a href="{% url 'subscribe' %}?sub_plan=Extended" class="btn db-button-color-square btn-lg">Subscribe with esewa</a>
                    <a href="{% url 'khaltirequest' %}?sub_plan=Extended" class="btn db-button-color-square btn-lg">Subscribe with khalti</a>
                </div>
            </div>
                  </div>
        </div>
    </div>

</div>
</div>
</body>
</html>