# Generated by Django 3.1 on 2022-04-30 13:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0003_auto_20220430_1815'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Esewa',
        ),
        migrations.DeleteModel(
            name='Khalti',
        ),
    ]
