<!DOCTYPE html>
<html>
<head>
    <title>Main Page</title>
    <link href="//maxcdn.bootstrapcdn.com/bootstrap/3.3.0/css/bootstrap.min.css" rel="stylesheet" id="bootstrap-css">
    <script src="//maxcdn.bootstrapcdn.com/bootstrap/3.3.0/js/bootstrap.min.js"></script>
    <script src="//code.jquery.com/jquery-1.11.1.min.js"></script>
</head>
<body>
    <div class="container">
    <a href="{% url 'logout'%}">logout</a>
        <p>Hi Am {{sub.user_membership}} I have a subscription plan.</p>
        <p class="alert btn-success">
            {{ sub.user_membership.membership }} Plan
        </p>
    </div>
 
 
</body>
</html>