# Generated by Django 3.1 on 2022-04-30 12:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='eSewa',
        ),
    ]
