<!DOCTYPE html>
<html>
<head>
    <title>Subscribed</title>
    <link href="//maxcdn.bootstrapcdn.com/bootstrap/3.3.0/css/bootstrap.min.css" rel="stylesheet" id="bootstrap-css">
    <script src="//maxcdn.bootstrapcdn.com/bootstrap/3.3.0/js/bootstrap.min.js"></script>
    <script src="//code.jquery.com/jquery-1.11.1.min.js"></script>
</head>
<body>
    <div class="container">
    <div class="row text-center">
        <div class="col-sm-6 col-sm-offset-3">
        <br><br> <h2 style="color:#0fad00">Success</h2>
        <i class="glyphicon glyphicon-success"></i>
        <h3>Dear, {{ request.user.first_name }}</h3>
        <p style="font-size:20px;color:#5C5C5C;">Thank you for subscribing to {{ plan }} Plan. We are so grateful and delight to have you back.</p>
        <a href="{% url 'home' %}" class="btn btn-success">     Continue      </a>
    <br><br>
        </div>
        
    </div>
</div>
</body>
</html>