# Generated by Django 3.1 on 2022-04-30 13:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0002_delete_esewa'),
    ]

    operations = [
        migrations.CreateModel(
            name='eSewa',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('merchant_id', models.CharField(default='epay_payment', max_length=100)),
            ],
        ),
    ]
